<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Archie Pro
 * @since Archie Pro 1.0.0
 * @return array An array of default values
 */

function archie_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$archie_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'red',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'menu_type'						=> 'modern-menu',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'archie-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'archie-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'archie-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Main Slider,Services,About Us,Video,Latest,Blog,Testimonial,Client,Call to Action',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'archie-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_comment'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_email'					=> 'info@themepalace.com',
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'archie-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Learn More', 'archie-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_btn_title'				=> esc_html__( 'Learn More', 'archie-pro' ),
		'about_title'					=> esc_html__( 'White high rise building by Michal Nowak', 'archie-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'archie-pro' ),

		// video
		'video_section_enable'			=> true,
		'video_image'					=> get_template_directory_uri() . '/assets/uploads/video.jpg',
		'video_title'					=> esc_html__( 'Video of the week', 'archie-pro' ),
		'video_description'				=> esc_html__( 'In lobortis nisl ornare enim sodales, a cursusnisl lacinia. Mauris nec facilisis est.', 'archie-pro' ),
		'video_section_url'				=> esc_url_raw( 'https://www.youtube.com/watch?v=0g95kNDC1VU' ),

		// Latest
		'latest_section_enable'			=> true,
		'latest_count'					=> 4,
		'latest_content_type'			=> 'category',
		'latest_title'					=> esc_html__( 'Projects', 'archie-pro' ),
		'latest_subtitle'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit.Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet.', 'archie-pro' ),
		'latest_btn_title'				=> esc_html__( 'View All', 'archie-pro' ),
		'latest_btn_url'				=> '#',

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',
		'service_btn_label'				=> esc_html__( 'View All', 'archie-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Blogs', 'archie-pro' ),
		'blog_subtitle'					=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit.Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet.', 'archie-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All', 'archie-pro' ),
		'blog_btn_url'					=> '#',

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_icon'				=> 'fa-university',
		'cta_content_type'				=> 'custom',
		'cta_title'						=> esc_html__( 'Archietecture starts when you carefully put two bricks together.', 'archie-pro' ),
		'cta_btn_title'					=> esc_html__( 'Learn More', 'archie-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,
		'testimonial_title'				=> esc_html__( 'Their thoughts', 'archie-pro' ),
		'testimonial_subtitle'			=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet.', 'archie-pro' ),

		// clients
		'client_section_enable'			=> true,
		'client_column'					=> 5,
		'client_content_type'			=> 'category',
		'client_count'					=> 6,
		
	);

	$output = apply_filters( 'archie_pro_default_theme_options', $archie_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}