<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Theme Palace
 * @subpackage Archie Pro
 * @since Archie Pro 1.0.0
 */

if ( ! function_exists( 'archie_pro_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function archie_pro_posted_on( $id = '' ) {
		if ( false === archie_pro_archive_meta_option( 'hide_date' ) ) {
			return;
		}

		$id = ! empty( $id ) ? $id : get_the_id();
		$time_string = '<time class="entry-date published updated" datetime="%1$s"><span class="date">%2$s</span><span class="month">%3$s</span></time>';
		if ( get_the_time( 'U', $id ) !== get_the_modified_time( 'U', $id ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s"><span class="date">%2$s</span><span class="month">%3$s</span></time><time class="updated" datetime="%4$s">%5$s</time>';
		}

		$time_string = sprintf( $time_string,
			get_the_date( DATE_W3C, $id ),
			get_the_date( 'd', $id ),
			get_the_date( 'M', $id ),
			get_the_modified_date( DATE_W3C, $id ),
			get_the_modified_date( '', $id )
		);

		$year = get_the_date( 'Y' );
		$month = get_the_date( 'm' );

		// Wrap the time string in a link, and preface it with 'Posted on'.
		printf(
			/* translators: %s: post date */
			__( '<span class="posted-on"><span class="screen-reader-text">Posted on</span> %s', 'archie-pro' ),
			'<a href="' . esc_url( get_month_link( $year, $month ) ) . '" rel="bookmark">' . $time_string . '</a></span>'
		);
	}
endif;

if ( ! function_exists( 'archie_pro_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the tags and comments.
	 */
	function archie_pro_entry_footer() {
		$options = archie_pro_get_theme_options();

		if ( ! $options['single_post_hide_category'] ) :
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'archie-pro' ) );
			if ( $categories_list && archie_pro_categorized_blog() ) {
				printf( '<span class="post-categories"><span class="cat-links">' . '%1$s' . '</span></span>', $categories_list ); // WPCS: XSS OK.
			}
		endif;

		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			if ( ! $options['single_post_hide_tags'] ) :
				/* translators: used between list items, there is a space after the comma */
				$tags_list = get_the_tag_list();
				if ( $tags_list ) {
					printf( '<span class="tags-links">%1$s</span>', $tags_list ); // WPCS: XSS OK.
				}
			endif;
		}

		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				esc_html__( 'Edit %s', 'archie-pro' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

/**
 * articles meta
 *  @param [id] $id post id
 *  @param [html] $authro author template
 */
function archie_pro_article_header_meta( $id = '' ) { 
	$id = ! empty( $id ) ? $id : get_the_id();

	if ( 'post' !== get_post_type( $id ) ) { 
		return;
	}
	$output = '';
	
	if ( true === archie_pro_archive_meta_option( 'hide_category' ) ) {
	    $categories_list = get_the_category_list( '', '', $id );
		if ( $categories_list && archie_pro_categorized_blog() ) {
			$output .= '<span class="cat-links">' . $categories_list . '</span>'; // WPCS: XSS OK.
		}
	}

	if ( true === archie_pro_archive_meta_option( 'hide_author' ) ) {
		$author = '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>';
	    $output .= '<span class="byline">' . $author . '</span><!-- .byline -->'; 
	}

	if ( true === archie_pro_archive_meta_option( 'hide_comment' ) ) {
	    if ( ! post_password_required( $id ) ) :
			if ( get_comments_number( $id ) <= 1 )
				$comment = sprintf( esc_html__( '%d comment', 'archie-pro' ), get_comments_number( $id ) ); 
			else
				$comment = sprintf( esc_html__( '%d comments', 'archie-pro' ), get_comments_number( $id ) ); 
		endif;
	}

    if ( ! empty( $comment ) ) :
        $output .= '<span class="comments-link"><a href="' . esc_url( get_comments_link( $id ) ) . '">' . $comment . '</a></span>';
    endif; 

    return $output;
}


/**
 * Checks to see if meta option is hide enabled in archive/blog
 */
function archie_pro_archive_meta_option( $option = '' ) {
	$options = archie_pro_get_theme_options();
	if ( is_archive() || is_search() || is_home() ) :
		if ( true === $options[$option] )
			return false;
		else
			return true;
	else :
		return true;
	endif;
}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function archie_pro_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'archie_pro_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'archie_pro_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so archie_pro_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so archie_pro_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in archie_pro_categorized_blog.
 */
function archie_pro_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'archie_pro_categories' );
}
add_action( 'edit_category', 'archie_pro_category_transient_flusher' );
add_action( 'save_post',     'archie_pro_category_transient_flusher' );
